@@ -170,7 +170,7 @@ class Measures(ABC):
         return df_measures.add_prefix('feature_')
 
 
-class Learner(ABC):
+class LearnersPool(ABC):
     """
     Base class for learners (algorithms). This class provides methods for assessing performance in a pool of learners.
     """
@@ -217,6 +217,13 @@ class Learner(ABC):
 
 
 class BaseApp:
+    """
+    Base class for user application (app). This class provides methods for drawing footprint areas, selecting instances,
+    generating plots, and populating tabs.
+
+    Args:
+        workspace (Workspace): loaded workspace instance
+    """
     _tabs_id = ['Instance Space', 'Footprint performance', 'Distributions', 'Data explorer']
     _tabs_inner_id = ['Meta-features', 'Features']
 
@@ -247,7 +254,16 @@ class BaseApp:
         poly_list = np.split(footprint, np.argwhere(np.isnan(footprint).any(axis=1)).flatten())
         return MultiPolygon(list(map(lambda x: Polygon(x[~np.isnan(x).any(axis=1)]), poly_list)))
 
-    def footprint_area(self, algo):
+    def footprint_area(self, algo: str):
+        """
+        Draws footprint area of a given algorithm.
+
+        Args:
+            algo (str): algorithm name
+
+        Returns:
+            Polygon plot with good and bad footprints
+        """
         try:
             border_points_good = self.workspace.footprints.xs((algo, 'good')).values
         except KeyError:
@@ -275,6 +291,9 @@ class BaseApp:
         return footprint_good * footprint_best
 
     def select_instances(self) -> Union[pd.Series, pd.DataFrame]:
+        """
+        Returns a mask of the instances within the selection.
+        """
         if self.bbox is None:
             return pd.Series(False, index=self.data.index)
         x, y = list(self.bbox.keys())
@@ -291,6 +310,16 @@ class BaseApp:
         return mask
 
     def select_footprint_instances(self, ftype: str = 'good') -> list:
+        """
+        Returns a mask of the instances within the current footprint.
+
+        Args:
+            ftype: type of footprint ('good' or 'bad')
+
+        Returns:
+            list: instance mask
+
+        """
         Z = self.workspace.is_coordinates.values
         algo = self.w_footprint_algo.value
         try:
@@ -302,13 +331,43 @@ class BaseApp:
 
     @abstractmethod
     def data_space(self, color: str, range_limits: Tuple[Number, Number], autorange_on: bool) -> hv.Scatter:
+        """
+        Creates the data space (PCA) plot.
+
+        Args:
+            color: name of the variable to color by
+            range_limits: color bar ranges
+            autorange_on: whether to use auto range for color bar
+
+        Returns:
+            Data space scatter plot
+
+        """
         pass
 
     @abstractmethod
     def instance_space(self, color: str, range_limits: Tuple[Number, Number], autorange_on: bool) -> hv.Scatter:
+        """
+        Creates the instance space plot.
+
+        Args:
+            color: name of the variable to color by
+            range_limits: color bar ranges
+            autorange_on: whether to use auto range for color bar
+
+        Returns:
+            Instance Space scatter plot
+
+        """
         pass
 
     def get_pane(self) -> pn.Template:
+        """
+        Builds and returns the entire panel, with tabs and plots.
+
+        Returns:
+            panel Template
+        """
         @pn.depends(color=self.w_color.param.value, lim=self.w_color_range.param.value,
                     autorange_on=self.w_checkbox.param.value)
         def update_plot1(color, lim, autorange_on):
@@ -412,9 +471,21 @@ class BaseApp:
 
     @abstractmethod
     def populate_tabs(self):
+        """
+        Populates the panel tabs.
+        """
         pass
 
-    def show(self, port: int = 5001, show: bool = True, ntries: int = 5):
+    def start(self, port: int = 5001, show: bool = True, ntries: int = 5):
+        """
+        Starts the application server.
+
+        Args:
+            port (int): attempts first to use this port. If it is in use, increments by 1 and try again until `ntries`
+                is reached
+            show: whether to open the browser and show the app
+            ntries: maximum number of increments to try if `port` is in use
+        """
         self.populate_tabs()
         for _ in range(ntries):
             try:
