@@ -1,3 +1,7 @@
+"""
+Module that gathers wrapper functions for the IS building steps.
+"""
+
 import glob
 import json
 import logging
@@ -13,14 +17,14 @@ from typing import Union, Tuple
 import pandas as pd
 from deprecation import deprecated
 from pyispace import train_is
+from pyispace.train import Model
 from pyispace.utils import scriptcsv
 
-from .classification import Classifier
+from .classification import ClassifiersPool
 from .feature_selection import featfilt
 from .measures import ClassificationMeasures
 from .structures import Configurations
 
-
 metadata_file = 'metadata.csv'
 options_file = 'options.json'
 ih_file = 'ih.csv'
@@ -34,13 +38,31 @@ _mcr_envvar_value = "/usr/local/MATLAB/MATLAB_Runtime/v98/runtime/glnxa64:" \
                     "/usr/local/MATLAB/MATLAB_Runtime/v98/extern/bin/glnxa64"
 
 
-def build_metadata(data: pd.DataFrame, config: Configurations,
-                   return_ih: bool = False, verbose=False) -> Union[Tuple[pd.DataFrame, pd.DataFrame], pd.DataFrame]:
+def build_metadata(
+        data: pd.DataFrame,
+        config: Configurations,
+        return_ih: bool = False,
+        verbose: bool = False
+) -> Union[Tuple[pd.DataFrame, pd.DataFrame], pd.DataFrame]:
+    """
+    Wrapper function that builds the metadata set.
+
+    Args:
+        data (pandas.DataFrame): input dataset
+        config (Configurations): configuration object
+        return_ih (bool): whether to return instance hardness array of values
+        verbose (bool): controls verbosity
+
+    Returns:
+        (pandas.DataFrame, pandas.DataFrame): The metadata set, and instance hardness values (optional, depending on
+        `return_ih`)
+
+    """
     problem = config.general.problem
     target_col = config.general.target_col
     if problem == 'classification':
         measures = ClassificationMeasures(data, target_col=target_col)
-        learners = Classifier(data, labels_col=target_col)
+        learners = ClassifiersPool(data, labels_col=target_col)
     elif problem == 'regression':
         # measures = ...
         # learners = ...
@@ -48,12 +70,10 @@ def build_metadata(data: pd.DataFrame, config: Configurations,
     else:
         raise ValueError(f"Unknown type of problem: '{problem}'.")
 
-    # m_params = {k: kwargs.get(k) for k in get_param_names(measures.calculate_all) if kwargs.get(k) is not None}
     df_measures = measures.calculate_all(
         measures_list=config.measures.list
     )
 
-    # c_params = {k: kwargs.get(k) for k in get_param_names(learners.run_all) if kwargs.get(k) is not None}
     df_algo = learners.run_all(
         metric=config.algos.metric,
         n_folds=config.algos.n_folds,
@@ -80,8 +100,29 @@ def build_metadata(data: pd.DataFrame, config: Configurations,
         return df_metadata
 
 
-def run_isa(rootdir: Path, metadata: Union[pd.DataFrame, Path] = None, settings: dict = None,
-            save_output: bool = True, rotation_adjust: bool = True, verbose: bool = False):
+def run_isa(
+        rootdir: Path,
+        metadata: Union[pd.DataFrame, Path] = None,
+        settings: dict = None,
+        save_output: bool = True,
+        rotation_adjust: bool = True,
+        verbose: bool = False
+) -> Model:
+    """
+    Run Instance Space Analysis with Python engine (PyISpace).
+
+    Args:
+        rootdir (Path): rootdir path
+        metadata (pandas.DataFrame or Path): the metadata or a path pointing to it
+        settings (dict): optional settings to update
+        save_output (bool): whether to save output files
+        rotation_adjust (bool): whether to adjust IS rotation
+        verbose (bool): controls verbosity
+
+    Returns:
+        ISA outputs
+
+    """
     if rotation_adjust is None:
         rotation_adjust = False
 
@@ -115,6 +156,11 @@ def run_isa(rootdir: Path, metadata: Union[pd.DataFrame, Path] = None, settings:
     return out
 
 
+@deprecated(
+    deprecated_in='1.9.4',
+    removed_in='2.0',
+    details="discontinued Matlab engine"
+)
 def run_matilda(rootdir, matildadir, metadata=None):
     """
     This is a wrapper function to call Matilda Matlab routine via Python.
@@ -153,6 +199,11 @@ def run_matilda(rootdir, matildadir, metadata=None):
     eng.trainIS(f'{rootdir}{os.sep}', nargout=0)
 
 
+@deprecated(
+    deprecated_in='1.9.4',
+    removed_in='2.0',
+    details="discontinued Matlab engine"
+)
 def run_matilda_module(rootdir):
     matilda = import_module('matilda')
     obj = matilda.initialize()
@@ -171,9 +222,11 @@ def update_options(d1: dict, d2: dict):
     return d1
 
 
-@deprecated(deprecated_in='1.7.4',
-            removed_in='2.0.0',
-            details="only used in module graphene, which was discontinued")
+@deprecated(
+    deprecated_in='1.7.4',
+    removed_in='2.0',
+    details="only used in module graphene, which was discontinued"
+)
 def clear_cache():
     files = glob.glob(str(_cache_path / '*'))
     for f in files:
@@ -183,9 +236,11 @@ def clear_cache():
             pass
 
 
-@deprecated(deprecated_in='1.7.4',
-            removed_in='2.0.0',
-            details="only used in module graphene, which was discontinued")
+@deprecated(
+    deprecated_in='1.7.4',
+    removed_in='2.0',
+    details="only used in module graphene, which was discontinued"
+)
 def _set_environment():
     # delete cached files from previous run
     clear_cache()
@@ -197,9 +252,11 @@ def _set_environment():
         os.environ[_mcr_envvar] = _mcr_envvar_value
 
 
-@deprecated(deprecated_in='1.7.4',
-            removed_in='2.0.0',
-            details="only used in module graphene, which was discontinued")
+@deprecated(
+    deprecated_in='1.7.4',
+    removed_in='2.0',
+    details="only used in module graphene, which was discontinued"
+)
 def run_pipeline(df_data: pd.DataFrame, configurations: dict):
     logger = logging.getLogger(__name__)
     logging.getLogger().setLevel(logging.INFO)
@@ -234,9 +291,11 @@ def run_pipeline(df_data: pd.DataFrame, configurations: dict):
     logger.info("Instance Hardness analysis finished.")
 
 
-@deprecated(deprecated_in='1.7.4',
-            removed_in='2.0.0',
-            details="only used in module graphene, which was discontinued")
+@deprecated(
+    deprecated_in='1.7.4',
+    removed_in='2.0',
+    details="only used in module graphene, which was discontinued"
+)
 def load_cached_files():
     df_data = pd.read_csv(_cache_path / 'data.csv')
     df_metadata = pd.read_csv(_cache_path / metadata_file, index_col=instances_index)
