@@ -1,3 +1,7 @@
+"""
+This module provides structures (dataclasses) that accommodate configurations for each step of the framework.
+"""
+
 from copy import deepcopy
 from dataclasses import asdict, dataclass, field, fields
 from pathlib import Path
@@ -6,6 +10,9 @@ from typing import Dict, Union, List
 
 @dataclass
 class GeneralConfig:
+    """
+    General configurations.
+    """
     rootdir: Union[str, Path]
     datafile: Union[str, Path]
     matildadir: Union[str, Path] = None
@@ -22,11 +29,17 @@ class GeneralConfig:
 
 @dataclass(frozen=True)
 class MeasuresConfig:
+    """
+    Configurations relative to the hardness measures.
+    """
     list: List[str]
 
 
 @dataclass(frozen=True)
 class AlgorithmsConfig:
+    """
+    Configurations relative to the pool of algorithms.
+    """
     pool: List[str]
     parameters: dict = field(default_factory=dict)
     n_folds: int = 5
@@ -36,6 +49,9 @@ class AlgorithmsConfig:
 
 @dataclass(frozen=True)
 class ISAConfig:
+    """
+    Instance Space Analysis configurations.
+    """
     engine: str = 'python'
     performance_threshold: Union[float, str] = 'auto'
     adjust_rotation: bool = True
@@ -45,6 +61,9 @@ class ISAConfig:
 
 @dataclass(frozen=True)
 class FSConfig:
+    """
+    Feature selection configurations.
+    """
     enabled: bool = True
     max_n_features: int = 10
     method: str = 'NCA'
@@ -57,6 +76,9 @@ class FSConfig:
 
 @dataclass(frozen=True)
 class HPOConfig:
+    """
+    Hyper-parameter optimization configurations.
+    """
     enabled: bool = True
     evals: int = 20
     timeout: int = 90
@@ -64,6 +86,9 @@ class HPOConfig:
 
 @dataclass(frozen=True)
 class Configurations:
+    """
+    Gathers all configurations in one class.
+    """
     general: GeneralConfig
     measures: MeasuresConfig
     algos: AlgorithmsConfig
