@@ -1,10 +1,10 @@
 import inspect
 import traceback
-import warnings
+from pathlib import Path
+from typing import Any, List, Union
 
-import pandas as pd
+import numpy as np
 import yaml
-from pandas.api.types import is_numeric_dtype, is_integer_dtype, is_float_dtype
 from sklearn.decomposition import PCA
 from sklearn.discriminant_analysis import LinearDiscriminantAnalysis
 from sklearn.neighbors import NeighborhoodComponentsAnalysis
@@ -12,7 +12,16 @@ from sklearn.pipeline import make_pipeline
 from sklearn.preprocessing import StandardScaler
 
 
-def load_yaml_file(path):
+def load_yaml_file(path: Union[str, Path]) -> dict:
+    """
+    Helping function to load YAML files.
+
+    Args:
+        path (str or Path): file path
+
+    Returns:
+        dict: loaded file
+    """
     try:
         with open(path, 'r') as file:
             try:
@@ -23,7 +32,14 @@ def load_yaml_file(path):
         traceback.print_exc()
 
 
-def write_yaml_file(data, path):
+def write_yaml_file(data: dict, path: Union[str, Path]):
+    """
+    Helping function to write YAML files.
+
+    Args:
+        data (dict): data to be written
+        path (str or Path): file path
+    """
     with open(path, 'w') as file:
         try:
             return yaml.dump(data, file, default_flow_style=False)
@@ -31,18 +47,39 @@ def write_yaml_file(data, path):
             traceback.print_exc()
 
 
-def get_param_names(method):
+def get_param_names(method) -> List[str]:
+    """
+    Helping function to get parameters of a given method.
+
+    Args:
+        method: class method
+
+    Returns:
+        list: name of the parameters
+    """
     assert callable(method)
     sig = inspect.signature(method)
     parameters = [p for p in sig.parameters.values() if p.name != 'self' and p.kind != p.VAR_KEYWORD]
     return sorted([p.name for p in parameters])
 
 
-def call_module_func(module, name, *args, **kwargs):
+def call_module_func(module, name, *args, **kwargs) -> Any:
+    """
+    Calls a module function by its name.
+
+    Args:
+        module: a module
+        name (str): name of the function
+        *args: function args
+        **kwargs: function kwargs
+
+    Returns:
+        The value returned by the called function
+    """
     return getattr(module, name)(*args, **kwargs)
 
 
-def reduce_dim(X, y, n_dim=2, method='LDA'):
+def reduce_dim(X: np.ndarray, y: np.ndarray, n_dim: int = 2, method: str = 'LDA'):
     method = str.upper(method)
     if method == 'LDA':
         model = make_pipeline(StandardScaler(), LinearDiscriminantAnalysis(n_components=n_dim))
@@ -57,49 +94,37 @@ def reduce_dim(X, y, n_dim=2, method='LDA'):
     return X_embedded
 
 
-def print_progress_bar(iteration, total, prefix='', suffix='', decimals=1, length=100, fill='█', printEnd="\r"):
-    """
-    Call in a loop to create terminal progress bar
+def print_progress_bar(iteration, total, prefix='', suffix='', decimals=1, length=100, fill='█', print_end="\r"):
+    r"""
+    Call in a loop to create terminal progress bar.
+
+    Args:
+        iteration: current iteration
+        total: total iterations
+        prefix: prefix string
+        suffix: suffix string
+        decimals: positive number of decimals in percent complete
+        length: character length of bar
+        fill: bar fill character
+        print_end: end character (e.g. \r, \r\n)
 
-    :param iteration: current iteration
-    :type iteration: int
-    :param total: total iterations
-    :type total: int
-    :param prefix: prefix string
-    :type prefix: str
-    :param suffix: suffix string
-    :type suffix: str
-    :param decimals: positive number of decimals in percent complete
-    :type decimals: int
-    :param length: character length of bar
-    :type length: int
-    :param fill: bar fill character
-    :type fill: str
-    :param printEnd: end character (e.g. "\r", "\r\n")
-    :type printEnd: str
     """
     percent = ("{0:." + str(decimals) + "f}").format(100 * (iteration / float(total)))
     filledLength = int(length * iteration // total)
     bar = fill * filledLength + ' ' * (length - filledLength)
-    print(f'\r{prefix} |{bar}| {percent}% {suffix}', end=printEnd)
+    print(f'\r{prefix} |{bar}| {percent}% {suffix}', end=print_end)
     # Print New Line on Complete
     if iteration == total:
         print()
 
 
-def check_dtype_consistency(s: pd.Series, expected_type: str) -> bool:
-    if expected_type == 'classification':
-        if is_float_dtype(s):
-            return False
-    elif expected_type == 'regression':
-        if not is_numeric_dtype(s):
-            return False
-        elif is_integer_dtype(s):
-            warnings.warn("")
-    return True
+def pretty_time_delta(seconds: int):
+    """
+    Pretty print time delta.
 
-
-def pretty_time_delta(seconds):
+    Args:
+        seconds (int): elapsed time
+    """
     seconds = int(seconds)
     days, seconds = divmod(seconds, 86400)
     hours, seconds = divmod(seconds, 3600)
