@@ -77,7 +77,7 @@ class AppClassification(BaseApp):
                                                     button_type='default', value='Continuous')
         self.w_var_s = pn.widgets.DiscreteSlider(name='Size', options=list(range(1, 16)), value=7)
 
-        val = 'instance_hardness' if 'instance_hardness' in df_footprint.index else ''
+        val = 'instance_easiness' if 'instance_easiness' in df_footprint.index else ''
         self.w_footprint_algo = pn.widgets.Select(options=df_footprint.index.unique(level='algo').to_list(), value=val)
 
         # self.populate_tabs()
